@@ -35,7 +35,7 @@ static OPENCV_BRANCH_32: Lazy<VersionReq> = Lazy::new(|| VersionReq::parse("~3.2
 static OPENCV_BRANCH_34: Lazy<VersionReq> = Lazy::new(|| VersionReq::parse("~3.4").expect("Can't parse OpenCV 3.4 version requirement"));
 static OPENCV_BRANCH_4: Lazy<VersionReq> = Lazy::new(|| VersionReq::parse("~4").expect("Can't parse OpenCV 4 version requirement"));
 
-static ENV_VARS: [&str; 16] = [
+static ENV_VARS: [&str; 14] = [
 	"OPENCV_PACKAGE_NAME",
 	"OPENCV_PKGCONFIG_NAME",
 	"OPENCV_CMAKE_NAME",
@@ -45,8 +45,6 @@ static ENV_VARS: [&str; 16] = [
 	"OPENCV_LINK_PATHS",
 	"OPENCV_INCLUDE_PATHS",
 	"OPENCV_DISABLE_PROBES",
-	"OPENCV_MODULE_WHITELIST",
-	"OPENCV_MODULE_BLACKLIST",
 	"CMAKE_PREFIX_PATH",
 	"OpenCV_DIR",
 	"PKG_CONFIG_PATH",
@@ -140,37 +138,31 @@ fn get_version_from_headers(header_dir: &Path) -> Option<Version> {
 }
 
 fn make_modules(opencv_dir: &Path) -> Result<()> {
-	let ignore_modules: HashSet<&'static str> = [
+	let ignore_modules = IntoIterator::into_iter([
 		"core_detect",
 		"cudalegacy",
 		"cudev",
 		"gapi",
 		"opencv",
 		"opencv_modules",
-	].iter().copied().collect();
-	let env_whitelist = env::var("OPENCV_MODULE_WHITELIST").ok();
-	let env_whitelist = env_whitelist.as_ref()
-		.map(|wl| wl.split(',')
-			.map(|e| e.trim())
-			.collect::<HashSet<_>>()
-		);
+	]).collect::<HashSet<_>>();
 
-	let env_blacklist = env::var("OPENCV_MODULE_BLACKLIST").ok();
-	let env_blacklist = env_blacklist.as_ref()
-		.map(|wl| wl.split(',')
-			.map(|e| e.trim())
-			.collect::<HashSet<_>>()
-		);
+	let enable_modules = IntoIterator::into_iter(["core".to_string()])
+		.chain(env::vars_os()
+			.filter_map(|(k, _)| k.to_str()
+				.and_then(|s| s.strip_prefix("CARGO_FEATURE_"))
+				.map(str::to_lowercase)
+			)
+		).collect::<HashSet<_>>();
 
-	let modules: Vec<String> = glob(&format!("{}/*.hpp", opencv_dir.to_str().ok_or("Can't OpenCV header directory to UTF-8 string")?))?
+	let modules = glob(&format!("{}/*.hpp", opencv_dir.to_str().ok_or("Can't OpenCV header directory to UTF-8 string")?))?
 		.filter_map(|entry| {
 			let entry = entry.expect("Can't get path for module file");
 			let module = entry.file_stem()
 				.and_then(OsStr::to_str).expect("Can't calculate file stem");
 			Some(module)
-				.filter(|m| !ignore_modules.contains(m))
-				.filter(|m| env_blacklist.as_ref().map_or(true, |bl| !bl.contains(m)))
-				.filter(|m| env_whitelist.as_ref().map_or(true, |wl| wl.contains(m)))
+				.filter(|&m| !ignore_modules.contains(m))
+				.filter(|&m| enable_modules.contains(m))
 				.map(str::to_string)
 		})
 		.collect();
@@ -193,7 +185,8 @@ fn build_compiler(opencv: &Library) -> cc::Build {
 		.flag_if_supported("-Wno-comment") // multi-line comment in include/opencv4/opencv2/mcc/ccm.hpp:73:25
 		// crate warnings
 		.flag_if_supported("-Wno-unused-variable") // ‘cv::CV_VERSION_OCVRS_OVERRIDE’ defined but not used
-		.flag_if_supported("-Wno-ignored-qualifiers") //  type qualifiers ignored on function return type in const size_t cv_MatStep_operator___const_int(const cv::MatStep* instance, int i)
+		.flag_if_supported("-Wno-ignored-qualifiers") // type qualifiers ignored on function return type in const size_t cv_MatStep_operator___const_int(const cv::MatStep* instance, int i)
+		.flag_if_supported("-Wnoreturn-type-c-linkage") // warning: 'cv_aruco_CharucoBoard_getChessboardSize_const' has C-linkage specified, but returns user-defined type 'Result<cv::Size>' (aka 'Result<Size_<int> >') which is incompatible with C
 	;
 	opencv.include_paths.iter().for_each(|p| { out.include(p); });
 	if cfg!(target_env = "msvc") {
@@ -203,6 +196,7 @@ fn build_compiler(opencv: &Library) -> cc::Build {
 			.flag_if_supported("-wd4996")
 			.flag_if_supported("-wd5054") // deprecated between enumerations of different types
 			.flag_if_supported("-wd4190") // has C-linkage specified, but returns UDT 'Result<cv::Rect_<int>>' which is incompatible with C
+			.flag_if_supported("-wd4702") // core.cpp(386) : unreachable code
 			.pic(false)
 		;
 	} else {
