@@ -19,9 +19,9 @@ elif [[ "$OS_FAMILY" == "osx" ]]; then
 		"$ci_dir/install-macos-framework.sh"
 	fi
 elif [[ "$OS_FAMILY" == "windows" ]]; then
-	if [[ "$CHOCO_OPENCV_VERSION" != "" ]]; then # chocolatey build
-		"$ci_dir/install-windows-chocolatey.sh"
-	else # vcpkg build
+	if [[ "$VCPKG_OPENCV_VERSION" != "" ]]; then # vcpkg build
 		"$ci_dir/install-windows-vcpkg.sh"
+	else # chocolatey build
+		"$ci_dir/install-windows-chocolatey.sh"
 	fi
 fi
