@@ -113,7 +113,8 @@ pub type uint8 = u8;
 /// * flags: DrawLinesMatchesFlags::DEFAULT
 #[inline]
 pub fn draw_keylines(image: &core::Mat, keylines: &core::Vector<crate::line_descriptor::KeyLine>, out_image: &mut core::Mat, color: core::Scalar, flags: i32) -> Result<()> {
-	unsafe { sys::cv_line_descriptor_drawKeylines_const_MatR_const_vector_KeyLine_R_MatR_const_ScalarR_int(image.as_raw_Mat(), keylines.as_raw_VectorOfKeyLine(), out_image.as_raw_mut_Mat(), &color, flags) }.into_result()
+	let ret = unsafe { sys::cv_line_descriptor_drawKeylines_const_MatR_const_vector_KeyLine_R_MatR_const_ScalarR_int(image.as_raw_Mat(), keylines.as_raw_VectorOfKeyLine(), out_image.as_raw_mut_Mat(), &color, flags) }.into_result()?;
+	Ok(ret)
 }
 
 /// Draws the found matches of keylines from two images.
@@ -141,7 +142,8 @@ pub fn draw_keylines(image: &core::Mat, keylines: &core::Vector<crate::line_desc
 /// * flags: DrawLinesMatchesFlags::DEFAULT
 #[inline]
 pub fn draw_line_matches(img1: &core::Mat, keylines1: &core::Vector<crate::line_descriptor::KeyLine>, img2: &core::Mat, keylines2: &core::Vector<crate::line_descriptor::KeyLine>, matches1to2: &core::Vector<core::DMatch>, out_img: &mut core::Mat, match_color: core::Scalar, single_line_color: core::Scalar, matches_mask: &core::Vector<i8>, flags: i32) -> Result<()> {
-	unsafe { sys::cv_line_descriptor_drawLineMatches_const_MatR_const_vector_KeyLine_R_const_MatR_const_vector_KeyLine_R_const_vector_DMatch_R_MatR_const_ScalarR_const_ScalarR_const_vector_char_R_int(img1.as_raw_Mat(), keylines1.as_raw_VectorOfKeyLine(), img2.as_raw_Mat(), keylines2.as_raw_VectorOfKeyLine(), matches1to2.as_raw_VectorOfDMatch(), out_img.as_raw_mut_Mat(), &match_color, &single_line_color, matches_mask.as_raw_VectorOfi8(), flags) }.into_result()
+	let ret = unsafe { sys::cv_line_descriptor_drawLineMatches_const_MatR_const_vector_KeyLine_R_const_MatR_const_vector_KeyLine_R_const_vector_DMatch_R_MatR_const_ScalarR_const_ScalarR_const_vector_char_R_int(img1.as_raw_Mat(), keylines1.as_raw_VectorOfKeyLine(), img2.as_raw_Mat(), keylines2.as_raw_VectorOfKeyLine(), matches1to2.as_raw_VectorOfDMatch(), out_img.as_raw_mut_Mat(), &match_color, &single_line_color, matches_mask.as_raw_VectorOfi8(), flags) }.into_result()?;
+	Ok(ret)
 }
 
 /// Class implements both functionalities for detection of lines and computation of their
@@ -159,7 +161,8 @@ pub trait BinaryDescriptorTraitConst: core::AlgorithmTraitConst {
 	/// * fs: output FileStorage file
 	#[inline]
 	fn write(&self, fs: &mut core::FileStorage) -> Result<()> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_write_const_FileStorageR(self.as_raw_BinaryDescriptor(), fs.as_raw_mut_FileStorage()) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_write_const_FileStorageR(self.as_raw_BinaryDescriptor(), fs.as_raw_mut_FileStorage()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Requires line detection
@@ -180,7 +183,8 @@ pub trait BinaryDescriptorTraitConst: core::AlgorithmTraitConst {
 	/// * masks: std::vector<Mat>()
 	#[inline]
 	fn detect(&self, images: &core::Vector<core::Mat>, keylines: &mut core::Vector<core::Vector<crate::line_descriptor::KeyLine>>, masks: &core::Vector<core::Mat>) -> Result<()> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_detect_const_const_vector_Mat_R_vector_vector_KeyLine__R_const_vector_Mat_R(self.as_raw_BinaryDescriptor(), images.as_raw_VectorOfMat(), keylines.as_raw_mut_VectorOfVectorOfKeyLine(), masks.as_raw_VectorOfMat()) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_detect_const_const_vector_Mat_R_vector_vector_KeyLine__R_const_vector_Mat_R(self.as_raw_BinaryDescriptor(), images.as_raw_VectorOfMat(), keylines.as_raw_mut_VectorOfVectorOfKeyLine(), masks.as_raw_VectorOfMat()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Requires descriptors computation
@@ -195,7 +199,8 @@ pub trait BinaryDescriptorTraitConst: core::AlgorithmTraitConst {
 	/// * return_float_descr: false
 	#[inline]
 	fn compute(&self, image: &core::Mat, keylines: &mut core::Vector<crate::line_descriptor::KeyLine>, descriptors: &mut core::Mat, return_float_descr: bool) -> Result<()> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_compute_const_const_MatR_vector_KeyLine_R_MatR_bool(self.as_raw_BinaryDescriptor(), image.as_raw_Mat(), keylines.as_raw_mut_VectorOfKeyLine(), descriptors.as_raw_mut_Mat(), return_float_descr) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_compute_const_const_MatR_vector_KeyLine_R_MatR_bool(self.as_raw_BinaryDescriptor(), image.as_raw_Mat(), keylines.as_raw_mut_VectorOfKeyLine(), descriptors.as_raw_mut_Mat(), return_float_descr) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Requires descriptors computation
@@ -218,25 +223,29 @@ pub trait BinaryDescriptorTraitConst: core::AlgorithmTraitConst {
 	/// * return_float_descr: false
 	#[inline]
 	fn compute_1(&self, images: &core::Vector<core::Mat>, keylines: &mut core::Vector<core::Vector<crate::line_descriptor::KeyLine>>, descriptors: &mut core::Vector<core::Mat>, return_float_descr: bool) -> Result<()> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_compute_const_const_vector_Mat_R_vector_vector_KeyLine__R_vector_Mat_R_bool(self.as_raw_BinaryDescriptor(), images.as_raw_VectorOfMat(), keylines.as_raw_mut_VectorOfVectorOfKeyLine(), descriptors.as_raw_mut_VectorOfMat(), return_float_descr) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_compute_const_const_vector_Mat_R_vector_vector_KeyLine__R_vector_Mat_R_bool(self.as_raw_BinaryDescriptor(), images.as_raw_VectorOfMat(), keylines.as_raw_mut_VectorOfVectorOfKeyLine(), descriptors.as_raw_mut_VectorOfMat(), return_float_descr) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Return descriptor size
 	#[inline]
 	fn descriptor_size(&self) -> Result<i32> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_descriptorSize_const(self.as_raw_BinaryDescriptor()) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_descriptorSize_const(self.as_raw_BinaryDescriptor()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Return data type
 	#[inline]
 	fn descriptor_type(&self) -> Result<i32> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_descriptorType_const(self.as_raw_BinaryDescriptor()) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_descriptorType_const(self.as_raw_BinaryDescriptor()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// returns norm mode
 	#[inline]
 	fn default_norm(&self) -> Result<i32> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_defaultNorm_const(self.as_raw_BinaryDescriptor()) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_defaultNorm_const(self.as_raw_BinaryDescriptor()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -247,7 +256,8 @@ pub trait BinaryDescriptorTrait: core::AlgorithmTrait + crate::line_descriptor::
 	/// Get current number of octaves
 	#[inline]
 	fn get_num_of_octaves(&mut self) -> Result<i32> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_getNumOfOctaves(self.as_raw_mut_BinaryDescriptor()) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_getNumOfOctaves(self.as_raw_mut_BinaryDescriptor()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Set number of octaves
@@ -255,13 +265,15 @@ pub trait BinaryDescriptorTrait: core::AlgorithmTrait + crate::line_descriptor::
 	/// * octaves: number of octaves
 	#[inline]
 	fn set_num_of_octaves(&mut self, octaves: i32) -> Result<()> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_setNumOfOctaves_int(self.as_raw_mut_BinaryDescriptor(), octaves) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_setNumOfOctaves_int(self.as_raw_mut_BinaryDescriptor(), octaves) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Get current width of bands
 	#[inline]
 	fn get_width_of_band(&mut self) -> Result<i32> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_getWidthOfBand(self.as_raw_mut_BinaryDescriptor()) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_getWidthOfBand(self.as_raw_mut_BinaryDescriptor()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Set width of bands
@@ -269,13 +281,15 @@ pub trait BinaryDescriptorTrait: core::AlgorithmTrait + crate::line_descriptor::
 	/// * width: width of bands
 	#[inline]
 	fn set_width_of_band(&mut self, width: i32) -> Result<()> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_setWidthOfBand_int(self.as_raw_mut_BinaryDescriptor(), width) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_setWidthOfBand_int(self.as_raw_mut_BinaryDescriptor(), width) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Get current reduction ratio (used in Gaussian pyramids)
 	#[inline]
 	fn get_reduction_ratio(&mut self) -> Result<i32> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_getReductionRatio(self.as_raw_mut_BinaryDescriptor()) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_getReductionRatio(self.as_raw_mut_BinaryDescriptor()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Set reduction ratio (used in Gaussian pyramids)
@@ -283,7 +297,8 @@ pub trait BinaryDescriptorTrait: core::AlgorithmTrait + crate::line_descriptor::
 	/// * rRatio: reduction ratio
 	#[inline]
 	fn set_reduction_ratio(&mut self, r_ratio: i32) -> Result<()> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_setReductionRatio_int(self.as_raw_mut_BinaryDescriptor(), r_ratio) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_setReductionRatio_int(self.as_raw_mut_BinaryDescriptor(), r_ratio) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Read parameters from a FileNode object and store them
@@ -292,7 +307,8 @@ pub trait BinaryDescriptorTrait: core::AlgorithmTrait + crate::line_descriptor::
 	/// * fn: source FileNode file
 	#[inline]
 	fn read(&mut self, fn_: &core::FileNode) -> Result<()> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_read_const_FileNodeR(self.as_raw_mut_BinaryDescriptor(), fn_.as_raw_FileNode()) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_read_const_FileNodeR(self.as_raw_mut_BinaryDescriptor(), fn_.as_raw_FileNode()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Requires line detection
@@ -306,7 +322,8 @@ pub trait BinaryDescriptorTrait: core::AlgorithmTrait + crate::line_descriptor::
 	/// * mask: Mat()
 	#[inline]
 	fn detect_1(&mut self, image: &core::Mat, keypoints: &mut core::Vector<crate::line_descriptor::KeyLine>, mask: &core::Mat) -> Result<()> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_detect_const_MatR_vector_KeyLine_R_const_MatR(self.as_raw_mut_BinaryDescriptor(), image.as_raw_Mat(), keypoints.as_raw_mut_VectorOfKeyLine(), mask.as_raw_Mat()) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_detect_const_MatR_vector_KeyLine_R_const_MatR(self.as_raw_mut_BinaryDescriptor(), image.as_raw_Mat(), keypoints.as_raw_mut_VectorOfKeyLine(), mask.as_raw_Mat()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -361,19 +378,25 @@ impl BinaryDescriptor {
 	/// * parameters: BinaryDescriptor::Params()
 	#[inline]
 	pub fn new(parameters: &crate::line_descriptor::BinaryDescriptor_Params) -> Result<crate::line_descriptor::BinaryDescriptor> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_BinaryDescriptor_const_ParamsR(parameters.as_raw_BinaryDescriptor_Params()) }.into_result().map(|r| unsafe { crate::line_descriptor::BinaryDescriptor::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_BinaryDescriptor_const_ParamsR(parameters.as_raw_BinaryDescriptor_Params()) }.into_result()?;
+		let ret = unsafe { crate::line_descriptor::BinaryDescriptor::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 	/// Create a BinaryDescriptor object with default parameters (or with the ones provided)
 	/// and return a smart pointer to it
 	#[inline]
 	pub fn create_binary_descriptor() -> Result<core::Ptr<crate::line_descriptor::BinaryDescriptor>> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_createBinaryDescriptor() }.into_result().map(|r| unsafe { core::Ptr::<crate::line_descriptor::BinaryDescriptor>::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_createBinaryDescriptor() }.into_result()?;
+		let ret = unsafe { core::Ptr::<crate::line_descriptor::BinaryDescriptor>::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 	#[inline]
 	pub fn create_binary_descriptor_1(mut parameters: crate::line_descriptor::BinaryDescriptor_Params) -> Result<core::Ptr<crate::line_descriptor::BinaryDescriptor>> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_createBinaryDescriptor_Params(parameters.as_raw_mut_BinaryDescriptor_Params()) }.into_result().map(|r| unsafe { core::Ptr::<crate::line_descriptor::BinaryDescriptor>::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_createBinaryDescriptor_Params(parameters.as_raw_mut_BinaryDescriptor_Params()) }.into_result()?;
+		let ret = unsafe { core::Ptr::<crate::line_descriptor::BinaryDescriptor>::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 }
@@ -387,30 +410,35 @@ pub trait BinaryDescriptor_ParamsTraitConst {
 	/// the number of image octaves (default = 1)
 	#[inline]
 	fn num_of_octave_(&self) -> i32 {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_Params_getPropNumOfOctave__const(self.as_raw_BinaryDescriptor_Params()) }.into_result().expect("Infallible function failed: num_of_octave_")
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_Params_getPropNumOfOctave__const(self.as_raw_BinaryDescriptor_Params()) };
+		ret
 	}
 	
 	/// the width of band; (default: 7)
 	#[inline]
 	fn width_of_band_(&self) -> i32 {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_Params_getPropWidthOfBand__const(self.as_raw_BinaryDescriptor_Params()) }.into_result().expect("Infallible function failed: width_of_band_")
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_Params_getPropWidthOfBand__const(self.as_raw_BinaryDescriptor_Params()) };
+		ret
 	}
 	
 	/// image's reduction ratio in construction of Gaussian pyramids
 	#[inline]
 	fn reduction_ratio(&self) -> i32 {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_Params_getPropReductionRatio_const(self.as_raw_BinaryDescriptor_Params()) }.into_result().expect("Infallible function failed: reduction_ratio")
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_Params_getPropReductionRatio_const(self.as_raw_BinaryDescriptor_Params()) };
+		ret
 	}
 	
 	#[inline]
 	fn ksize_(&self) -> i32 {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_Params_getPropKsize__const(self.as_raw_BinaryDescriptor_Params()) }.into_result().expect("Infallible function failed: ksize_")
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_Params_getPropKsize__const(self.as_raw_BinaryDescriptor_Params()) };
+		ret
 	}
 	
 	/// store parameters to a FileStorage object (struct function)
 	#[inline]
 	fn write(&self, fs: &mut core::FileStorage) -> Result<()> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_Params_write_const_FileStorageR(self.as_raw_BinaryDescriptor_Params(), fs.as_raw_mut_FileStorage()) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_Params_write_const_FileStorageR(self.as_raw_BinaryDescriptor_Params(), fs.as_raw_mut_FileStorage()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -421,30 +449,35 @@ pub trait BinaryDescriptor_ParamsTrait: crate::line_descriptor::BinaryDescriptor
 	/// the number of image octaves (default = 1)
 	#[inline]
 	fn set_num_of_octave_(&mut self, val: i32) {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_Params_setPropNumOfOctave__int(self.as_raw_mut_BinaryDescriptor_Params(), val) }.into_result().expect("Infallible function failed: set_num_of_octave_")
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_Params_setPropNumOfOctave__int(self.as_raw_mut_BinaryDescriptor_Params(), val) };
+		ret
 	}
 	
 	/// the width of band; (default: 7)
 	#[inline]
 	fn set_width_of_band_(&mut self, val: i32) {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_Params_setPropWidthOfBand__int(self.as_raw_mut_BinaryDescriptor_Params(), val) }.into_result().expect("Infallible function failed: set_width_of_band_")
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_Params_setPropWidthOfBand__int(self.as_raw_mut_BinaryDescriptor_Params(), val) };
+		ret
 	}
 	
 	/// image's reduction ratio in construction of Gaussian pyramids
 	#[inline]
 	fn set_reduction_ratio(&mut self, val: i32) {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_Params_setPropReductionRatio_int(self.as_raw_mut_BinaryDescriptor_Params(), val) }.into_result().expect("Infallible function failed: set_reduction_ratio")
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_Params_setPropReductionRatio_int(self.as_raw_mut_BinaryDescriptor_Params(), val) };
+		ret
 	}
 	
 	#[inline]
 	fn set_ksize_(&mut self, val: i32) {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_Params_setPropKsize__int(self.as_raw_mut_BinaryDescriptor_Params(), val) }.into_result().expect("Infallible function failed: set_ksize_")
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_Params_setPropKsize__int(self.as_raw_mut_BinaryDescriptor_Params(), val) };
+		ret
 	}
 	
 	/// read parameters from a FileNode object and store them (struct function)
 	#[inline]
 	fn read(&mut self, fn_: &core::FileNode) -> Result<()> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_Params_read_const_FileNodeR(self.as_raw_mut_BinaryDescriptor_Params(), fn_.as_raw_FileNode()) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_Params_read_const_FileNodeR(self.as_raw_mut_BinaryDescriptor_Params(), fn_.as_raw_FileNode()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -476,7 +509,9 @@ impl crate::line_descriptor::BinaryDescriptor_ParamsTrait for BinaryDescriptor_P
 impl BinaryDescriptor_Params {
 	#[inline]
 	pub fn default() -> Result<crate::line_descriptor::BinaryDescriptor_Params> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptor_Params_Params() }.into_result().map(|r| unsafe { crate::line_descriptor::BinaryDescriptor_Params::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptor_Params_Params() }.into_result()?;
+		let ret = unsafe { crate::line_descriptor::BinaryDescriptor_Params::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 }
@@ -534,7 +569,8 @@ pub trait BinaryDescriptorMatcherTraitConst: core::AlgorithmTraitConst {
 	/// * mask: Mat()
 	#[inline]
 	fn match_(&self, query_descriptors: &core::Mat, train_descriptors: &core::Mat, matches: &mut core::Vector<core::DMatch>, mask: &core::Mat) -> Result<()> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptorMatcher_match_const_const_MatR_const_MatR_vector_DMatch_R_const_MatR(self.as_raw_BinaryDescriptorMatcher(), query_descriptors.as_raw_Mat(), train_descriptors.as_raw_Mat(), matches.as_raw_mut_VectorOfDMatch(), mask.as_raw_Mat()) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptorMatcher_match_const_const_MatR_const_MatR_vector_DMatch_R_const_MatR(self.as_raw_BinaryDescriptorMatcher(), query_descriptors.as_raw_Mat(), train_descriptors.as_raw_Mat(), matches.as_raw_mut_VectorOfDMatch(), mask.as_raw_Mat()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// For every input query descriptor, retrieve the best *k* matching ones from a dataset provided from
@@ -554,7 +590,8 @@ pub trait BinaryDescriptorMatcherTraitConst: core::AlgorithmTraitConst {
 	/// * compact_result: false
 	#[inline]
 	fn knn_match(&self, query_descriptors: &core::Mat, train_descriptors: &core::Mat, matches: &mut core::Vector<core::Vector<core::DMatch>>, k: i32, mask: &core::Mat, compact_result: bool) -> Result<()> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptorMatcher_knnMatch_const_const_MatR_const_MatR_vector_vector_DMatch__R_int_const_MatR_bool(self.as_raw_BinaryDescriptorMatcher(), query_descriptors.as_raw_Mat(), train_descriptors.as_raw_Mat(), matches.as_raw_mut_VectorOfVectorOfDMatch(), k, mask.as_raw_Mat(), compact_result) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptorMatcher_knnMatch_const_const_MatR_const_MatR_vector_vector_DMatch__R_int_const_MatR_bool(self.as_raw_BinaryDescriptorMatcher(), query_descriptors.as_raw_Mat(), train_descriptors.as_raw_Mat(), matches.as_raw_mut_VectorOfVectorOfDMatch(), k, mask.as_raw_Mat(), compact_result) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// For every input query descriptor, retrieve, from a dataset provided from user or from the one
@@ -574,7 +611,8 @@ pub trait BinaryDescriptorMatcherTraitConst: core::AlgorithmTraitConst {
 	/// * compact_result: false
 	#[inline]
 	fn radius_match(&self, query_descriptors: &core::Mat, train_descriptors: &core::Mat, matches: &mut core::Vector<core::Vector<core::DMatch>>, max_distance: f32, mask: &core::Mat, compact_result: bool) -> Result<()> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptorMatcher_radiusMatch_const_const_MatR_const_MatR_vector_vector_DMatch__R_float_const_MatR_bool(self.as_raw_BinaryDescriptorMatcher(), query_descriptors.as_raw_Mat(), train_descriptors.as_raw_Mat(), matches.as_raw_mut_VectorOfVectorOfDMatch(), max_distance, mask.as_raw_Mat(), compact_result) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptorMatcher_radiusMatch_const_const_MatR_const_MatR_vector_vector_DMatch__R_float_const_MatR_bool(self.as_raw_BinaryDescriptorMatcher(), query_descriptors.as_raw_Mat(), train_descriptors.as_raw_Mat(), matches.as_raw_mut_VectorOfVectorOfDMatch(), max_distance, mask.as_raw_Mat(), compact_result) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -603,7 +641,8 @@ pub trait BinaryDescriptorMatcherTrait: core::AlgorithmTrait + crate::line_descr
 	/// * masks: std::vector<Mat>()
 	#[inline]
 	fn match_query(&mut self, query_descriptors: &core::Mat, matches: &mut core::Vector<core::DMatch>, masks: &core::Vector<core::Mat>) -> Result<()> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptorMatcher_match_const_MatR_vector_DMatch_R_const_vector_Mat_R(self.as_raw_mut_BinaryDescriptorMatcher(), query_descriptors.as_raw_Mat(), matches.as_raw_mut_VectorOfDMatch(), masks.as_raw_VectorOfMat()) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptorMatcher_match_const_MatR_vector_DMatch_R_const_vector_Mat_R(self.as_raw_mut_BinaryDescriptorMatcher(), query_descriptors.as_raw_Mat(), matches.as_raw_mut_VectorOfDMatch(), masks.as_raw_VectorOfMat()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// For every input query descriptor, retrieve the best *k* matching ones from a dataset provided from
@@ -634,7 +673,8 @@ pub trait BinaryDescriptorMatcherTrait: core::AlgorithmTrait + crate::line_descr
 	/// * compact_result: false
 	#[inline]
 	fn knn_match_query(&mut self, query_descriptors: &core::Mat, matches: &mut core::Vector<core::Vector<core::DMatch>>, k: i32, masks: &core::Vector<core::Mat>, compact_result: bool) -> Result<()> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptorMatcher_knnMatch_const_MatR_vector_vector_DMatch__R_int_const_vector_Mat_R_bool(self.as_raw_mut_BinaryDescriptorMatcher(), query_descriptors.as_raw_Mat(), matches.as_raw_mut_VectorOfVectorOfDMatch(), k, masks.as_raw_VectorOfMat(), compact_result) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptorMatcher_knnMatch_const_MatR_vector_vector_DMatch__R_int_const_vector_Mat_R_bool(self.as_raw_mut_BinaryDescriptorMatcher(), query_descriptors.as_raw_Mat(), matches.as_raw_mut_VectorOfVectorOfDMatch(), k, masks.as_raw_VectorOfMat(), compact_result) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// For every input query descriptor, retrieve, from a dataset provided from user or from the one
@@ -665,7 +705,8 @@ pub trait BinaryDescriptorMatcherTrait: core::AlgorithmTrait + crate::line_descr
 	/// * compact_result: false
 	#[inline]
 	fn radius_match_1(&mut self, query_descriptors: &core::Mat, matches: &mut core::Vector<core::Vector<core::DMatch>>, max_distance: f32, masks: &core::Vector<core::Mat>, compact_result: bool) -> Result<()> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptorMatcher_radiusMatch_const_MatR_vector_vector_DMatch__R_float_const_vector_Mat_R_bool(self.as_raw_mut_BinaryDescriptorMatcher(), query_descriptors.as_raw_Mat(), matches.as_raw_mut_VectorOfVectorOfDMatch(), max_distance, masks.as_raw_VectorOfMat(), compact_result) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptorMatcher_radiusMatch_const_MatR_vector_vector_DMatch__R_float_const_vector_Mat_R_bool(self.as_raw_mut_BinaryDescriptorMatcher(), query_descriptors.as_raw_Mat(), matches.as_raw_mut_VectorOfVectorOfDMatch(), max_distance, masks.as_raw_VectorOfMat(), compact_result) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Store locally new descriptors to be inserted in dataset, without updating dataset.
@@ -678,7 +719,8 @@ pub trait BinaryDescriptorMatcherTrait: core::AlgorithmTrait + crate::line_descr
 	/// *i*-th image.
 	#[inline]
 	fn add(&mut self, descriptors: &core::Vector<core::Mat>) -> Result<()> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptorMatcher_add_const_vector_Mat_R(self.as_raw_mut_BinaryDescriptorMatcher(), descriptors.as_raw_VectorOfMat()) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptorMatcher_add_const_vector_Mat_R(self.as_raw_mut_BinaryDescriptorMatcher(), descriptors.as_raw_VectorOfMat()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Update dataset by inserting into it all descriptors that were stored locally by *add* function.
@@ -688,13 +730,15 @@ pub trait BinaryDescriptorMatcherTrait: core::AlgorithmTrait + crate::line_descr
 	/// are inserted into dataset. The locally stored copy of just inserted descriptors is then removed.
 	#[inline]
 	fn train(&mut self) -> Result<()> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptorMatcher_train(self.as_raw_mut_BinaryDescriptorMatcher()) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptorMatcher_train(self.as_raw_mut_BinaryDescriptorMatcher()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Clear dataset and internal data
 	#[inline]
 	fn clear(&mut self) -> Result<()> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptorMatcher_clear(self.as_raw_mut_BinaryDescriptorMatcher()) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptorMatcher_clear(self.as_raw_mut_BinaryDescriptorMatcher()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -771,7 +815,9 @@ impl BinaryDescriptorMatcher {
 	/// Create a BinaryDescriptorMatcher object and return a smart pointer to it.
 	#[inline]
 	pub fn create_binary_descriptor_matcher() -> Result<core::Ptr<crate::line_descriptor::BinaryDescriptorMatcher>> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptorMatcher_createBinaryDescriptorMatcher() }.into_result().map(|r| unsafe { core::Ptr::<crate::line_descriptor::BinaryDescriptorMatcher>::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptorMatcher_createBinaryDescriptorMatcher() }.into_result()?;
+		let ret = unsafe { core::Ptr::<crate::line_descriptor::BinaryDescriptorMatcher>::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 	/// Constructor.
@@ -779,7 +825,9 @@ impl BinaryDescriptorMatcher {
 	/// The BinaryDescriptorMatcher constructed is able to store and manage 256-bits long entries.
 	#[inline]
 	pub fn default() -> Result<crate::line_descriptor::BinaryDescriptorMatcher> {
-		unsafe { sys::cv_line_descriptor_BinaryDescriptorMatcher_BinaryDescriptorMatcher() }.into_result().map(|r| unsafe { crate::line_descriptor::BinaryDescriptorMatcher::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_line_descriptor_BinaryDescriptorMatcher_BinaryDescriptorMatcher() }.into_result()?;
+		let ret = unsafe { crate::line_descriptor::BinaryDescriptorMatcher::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 }
@@ -858,31 +906,36 @@ impl KeyLine {
 	/// Returns the start point of the line in the original image
 	#[inline]
 	pub fn get_start_point(self) -> Result<core::Point2f> {
-		unsafe { sys::cv_line_descriptor_KeyLine_getStartPoint_const(self.opencv_as_extern()) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_KeyLine_getStartPoint_const(self.opencv_as_extern()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Returns the end point of the line in the original image
 	#[inline]
 	pub fn get_end_point(self) -> Result<core::Point2f> {
-		unsafe { sys::cv_line_descriptor_KeyLine_getEndPoint_const(self.opencv_as_extern()) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_KeyLine_getEndPoint_const(self.opencv_as_extern()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Returns the start point of the line in the octave it was extracted from
 	#[inline]
 	pub fn get_start_point_in_octave(self) -> Result<core::Point2f> {
-		unsafe { sys::cv_line_descriptor_KeyLine_getStartPointInOctave_const(self.opencv_as_extern()) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_KeyLine_getStartPointInOctave_const(self.opencv_as_extern()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Returns the end point of the line in the octave it was extracted from
 	#[inline]
 	pub fn get_end_point_in_octave(self) -> Result<core::Point2f> {
-		unsafe { sys::cv_line_descriptor_KeyLine_getEndPointInOctave_const(self.opencv_as_extern()) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_KeyLine_getEndPointInOctave_const(self.opencv_as_extern()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// constructor
 	#[inline]
 	pub fn default() -> Result<crate::line_descriptor::KeyLine> {
-		unsafe { sys::cv_line_descriptor_KeyLine_KeyLine() }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_KeyLine_KeyLine() }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -911,7 +964,8 @@ pub trait LSDDetectorTraitConst: core::AlgorithmTraitConst {
 	/// * masks: std::vector<Mat>()
 	#[inline]
 	fn detect_multiple(&self, images: &core::Vector<core::Mat>, keylines: &mut core::Vector<core::Vector<crate::line_descriptor::KeyLine>>, scale: i32, num_octaves: i32, masks: &core::Vector<core::Mat>) -> Result<()> {
-		unsafe { sys::cv_line_descriptor_LSDDetector_detect_const_const_vector_Mat_R_vector_vector_KeyLine__R_int_int_const_vector_Mat_R(self.as_raw_LSDDetector(), images.as_raw_VectorOfMat(), keylines.as_raw_mut_VectorOfVectorOfKeyLine(), scale, num_octaves, masks.as_raw_VectorOfMat()) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_LSDDetector_detect_const_const_vector_Mat_R_vector_vector_KeyLine__R_int_int_const_vector_Mat_R(self.as_raw_LSDDetector(), images.as_raw_VectorOfMat(), keylines.as_raw_mut_VectorOfVectorOfKeyLine(), scale, num_octaves, masks.as_raw_VectorOfMat()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -932,7 +986,8 @@ pub trait LSDDetectorTrait: core::AlgorithmTrait + crate::line_descriptor::LSDDe
 	/// * mask: Mat()
 	#[inline]
 	fn detect(&mut self, image: &core::Mat, keypoints: &mut core::Vector<crate::line_descriptor::KeyLine>, scale: i32, num_octaves: i32, mask: &core::Mat) -> Result<()> {
-		unsafe { sys::cv_line_descriptor_LSDDetector_detect_const_MatR_vector_KeyLine_R_int_int_const_MatR(self.as_raw_mut_LSDDetector(), image.as_raw_Mat(), keypoints.as_raw_mut_VectorOfKeyLine(), scale, num_octaves, mask.as_raw_Mat()) }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_LSDDetector_detect_const_MatR_vector_KeyLine_R_int_int_const_MatR(self.as_raw_mut_LSDDetector(), image.as_raw_Mat(), keypoints.as_raw_mut_VectorOfKeyLine(), scale, num_octaves, mask.as_raw_Mat()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -971,23 +1026,31 @@ impl crate::line_descriptor::LSDDetectorTrait for LSDDetector {
 impl LSDDetector {
 	#[inline]
 	pub fn default() -> Result<crate::line_descriptor::LSDDetector> {
-		unsafe { sys::cv_line_descriptor_LSDDetector_LSDDetector() }.into_result().map(|r| unsafe { crate::line_descriptor::LSDDetector::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_line_descriptor_LSDDetector_LSDDetector() }.into_result()?;
+		let ret = unsafe { crate::line_descriptor::LSDDetector::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 	#[inline]
 	pub fn new(_params: crate::line_descriptor::LSDParam) -> Result<crate::line_descriptor::LSDDetector> {
-		unsafe { sys::cv_line_descriptor_LSDDetector_LSDDetector_LSDParam(_params.opencv_as_extern()) }.into_result().map(|r| unsafe { crate::line_descriptor::LSDDetector::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_line_descriptor_LSDDetector_LSDDetector_LSDParam(_params.opencv_as_extern()) }.into_result()?;
+		let ret = unsafe { crate::line_descriptor::LSDDetector::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 	/// Creates ad LSDDetector object, using smart pointers.
 	#[inline]
 	pub fn create_lsd_detector() -> Result<core::Ptr<crate::line_descriptor::LSDDetector>> {
-		unsafe { sys::cv_line_descriptor_LSDDetector_createLSDDetector() }.into_result().map(|r| unsafe { core::Ptr::<crate::line_descriptor::LSDDetector>::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_line_descriptor_LSDDetector_createLSDDetector() }.into_result()?;
+		let ret = unsafe { core::Ptr::<crate::line_descriptor::LSDDetector>::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 	#[inline]
 	pub fn create_lsd_detector_with_params(params: crate::line_descriptor::LSDParam) -> Result<core::Ptr<crate::line_descriptor::LSDDetector>> {
-		unsafe { sys::cv_line_descriptor_LSDDetector_createLSDDetector_LSDParam(params.opencv_as_extern()) }.into_result().map(|r| unsafe { core::Ptr::<crate::line_descriptor::LSDDetector>::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_line_descriptor_LSDDetector_createLSDDetector_LSDParam(params.opencv_as_extern()) }.into_result()?;
+		let ret = unsafe { core::Ptr::<crate::line_descriptor::LSDDetector>::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 }
@@ -1026,7 +1089,8 @@ opencv_type_simple! { crate::line_descriptor::LSDParam }
 impl LSDParam {
 	#[inline]
 	pub fn default() -> Result<crate::line_descriptor::LSDParam> {
-		unsafe { sys::cv_line_descriptor_LSDParam_LSDParam() }.into_result()
+		let ret = unsafe { sys::cv_line_descriptor_LSDParam_LSDParam() }.into_result()?;
+		Ok(ret)
 	}
 	
 }
