@@ -408,7 +408,8 @@ pub trait ICPTrait: crate::surface_matching::ICPTraitConst {
 	/// \details It is assumed that the model is registered on the scene. Scene remains static, while the model transforms. The output poses transform the models onto the scene. Because of the point to plane minimization, the scene is expected to have the normals available. Expected to have the normals (Nx6).
 	#[inline]
 	fn register_model_to_scene(&mut self, src_pc: &core::Mat, dst_pc: &core::Mat, residual: &mut f64, pose: &mut core::Matx44d) -> Result<i32> {
-		unsafe { sys::cv_ppf_match_3d_ICP_registerModelToScene_const_MatR_const_MatR_doubleR_Matx44dR(self.as_raw_mut_ICP(), src_pc.as_raw_Mat(), dst_pc.as_raw_Mat(), residual, pose) }.into_result()
+		let ret = unsafe { sys::cv_ppf_match_3d_ICP_registerModelToScene_const_MatR_const_MatR_doubleR_Matx44dR(self.as_raw_mut_ICP(), src_pc.as_raw_Mat(), dst_pc.as_raw_Mat(), residual, pose) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// \brief Perform registration with multiple initial poses
@@ -423,7 +424,8 @@ pub trait ICPTrait: crate::surface_matching::ICPTraitConst {
 	/// \details It is assumed that the model is registered on the scene. Scene remains static, while the model transforms. The output poses transform the models onto the scene. Because of the point to plane minimization, the scene is expected to have the normals available. Expected to have the normals (Nx6).
 	#[inline]
 	fn register_model_to_scene_vec(&mut self, src_pc: &core::Mat, dst_pc: &core::Mat, poses: &mut core::Vector<crate::surface_matching::Pose3DPtr>) -> Result<i32> {
-		unsafe { sys::cv_ppf_match_3d_ICP_registerModelToScene_const_MatR_const_MatR_vector_Pose3DPtr_R(self.as_raw_mut_ICP(), src_pc.as_raw_Mat(), dst_pc.as_raw_Mat(), poses.as_raw_mut_VectorOfPose3DPtr()) }.into_result()
+		let ret = unsafe { sys::cv_ppf_match_3d_ICP_registerModelToScene_const_MatR_const_MatR_vector_Pose3DPtr_R(self.as_raw_mut_ICP(), src_pc.as_raw_Mat(), dst_pc.as_raw_Mat(), poses.as_raw_mut_VectorOfPose3DPtr()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -470,7 +472,9 @@ impl crate::surface_matching::ICPTrait for ICP {
 impl ICP {
 	#[inline]
 	pub fn default() -> Result<crate::surface_matching::ICP> {
-		unsafe { sys::cv_ppf_match_3d_ICP_ICP() }.into_result().map(|r| unsafe { crate::surface_matching::ICP::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_ppf_match_3d_ICP_ICP() }.into_result()?;
+		let ret = unsafe { crate::surface_matching::ICP::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 	/// \brief ICP constructor with default arguments.
@@ -496,7 +500,9 @@ impl ICP {
 	/// * num_max_corr: 1
 	#[inline]
 	pub fn new(iterations: i32, tolerence: f32, rejection_scale: f32, num_levels: i32, sample_type: i32, num_max_corr: i32) -> Result<crate::surface_matching::ICP> {
-		unsafe { sys::cv_ppf_match_3d_ICP_ICP_const_int_const_float_const_float_const_int_const_int_const_int(iterations, tolerence, rejection_scale, num_levels, sample_type, num_max_corr) }.into_result().map(|r| unsafe { crate::surface_matching::ICP::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_ppf_match_3d_ICP_ICP_const_int_const_float_const_float_const_int_const_int_const_int(iterations, tolerence, rejection_scale, num_levels, sample_type, num_max_corr) }.into_result()?;
+		let ret = unsafe { crate::surface_matching::ICP::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 }
@@ -532,7 +538,8 @@ pub trait PPF3DDetectorTrait: crate::surface_matching::PPF3DDetectorTraitConst {
 	/// * use_weighted_clustering: false
 	#[inline]
 	fn set_search_params(&mut self, position_threshold: f64, rotation_threshold: f64, use_weighted_clustering: bool) -> Result<()> {
-		unsafe { sys::cv_ppf_match_3d_PPF3DDetector_setSearchParams_const_double_const_double_const_bool(self.as_raw_mut_PPF3DDetector(), position_threshold, rotation_threshold, use_weighted_clustering) }.into_result()
+		let ret = unsafe { sys::cv_ppf_match_3d_PPF3DDetector_setSearchParams_const_double_const_double_const_bool(self.as_raw_mut_PPF3DDetector(), position_threshold, rotation_threshold, use_weighted_clustering) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// \brief Trains a new model.
@@ -543,7 +550,8 @@ pub trait PPF3DDetectorTrait: crate::surface_matching::PPF3DDetectorTraitConst {
 	/// \details Uses the parameters set in the constructor to downsample and learn a new model. When the model is learnt, the instance gets ready for calling "match".
 	#[inline]
 	fn train_model(&mut self, model: &core::Mat) -> Result<()> {
-		unsafe { sys::cv_ppf_match_3d_PPF3DDetector_trainModel_const_MatR(self.as_raw_mut_PPF3DDetector(), model.as_raw_Mat()) }.into_result()
+		let ret = unsafe { sys::cv_ppf_match_3d_PPF3DDetector_trainModel_const_MatR(self.as_raw_mut_PPF3DDetector(), model.as_raw_Mat()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// \brief Matches a trained model across a provided scene.
@@ -559,7 +567,8 @@ pub trait PPF3DDetectorTrait: crate::surface_matching::PPF3DDetectorTraitConst {
 	/// * relative_scene_distance: 0.03
 	#[inline]
 	fn match_(&mut self, scene: &core::Mat, results: &mut core::Vector<crate::surface_matching::Pose3DPtr>, relative_scene_sample_step: f64, relative_scene_distance: f64) -> Result<()> {
-		unsafe { sys::cv_ppf_match_3d_PPF3DDetector_match_const_MatR_vector_Pose3DPtr_R_const_double_const_double(self.as_raw_mut_PPF3DDetector(), scene.as_raw_Mat(), results.as_raw_mut_VectorOfPose3DPtr(), relative_scene_sample_step, relative_scene_distance) }.into_result()
+		let ret = unsafe { sys::cv_ppf_match_3d_PPF3DDetector_match_const_MatR_vector_Pose3DPtr_R_const_double_const_double(self.as_raw_mut_PPF3DDetector(), scene.as_raw_Mat(), results.as_raw_mut_VectorOfPose3DPtr(), relative_scene_sample_step, relative_scene_distance) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -602,7 +611,9 @@ impl PPF3DDetector {
 	/// \brief Empty constructor. Sets default arguments
 	#[inline]
 	pub fn default() -> Result<crate::surface_matching::PPF3DDetector> {
-		unsafe { sys::cv_ppf_match_3d_PPF3DDetector_PPF3DDetector() }.into_result().map(|r| unsafe { crate::surface_matching::PPF3DDetector::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_ppf_match_3d_PPF3DDetector_PPF3DDetector() }.into_result()?;
+		let ret = unsafe { crate::surface_matching::PPF3DDetector::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 	/// Constructor with arguments
@@ -616,7 +627,9 @@ impl PPF3DDetector {
 	/// * num_angles: 30
 	#[inline]
 	pub fn new(relative_sampling_step: f64, relative_distance_step: f64, num_angles: f64) -> Result<crate::surface_matching::PPF3DDetector> {
-		unsafe { sys::cv_ppf_match_3d_PPF3DDetector_PPF3DDetector_const_double_const_double_const_double(relative_sampling_step, relative_distance_step, num_angles) }.into_result().map(|r| unsafe { crate::surface_matching::PPF3DDetector::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_ppf_match_3d_PPF3DDetector_PPF3DDetector_const_double_const_double_const_double(relative_sampling_step, relative_distance_step, num_angles) }.into_result()?;
+		let ret = unsafe { crate::surface_matching::PPF3DDetector::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 }
@@ -629,42 +642,50 @@ pub trait Pose3DTraitConst {
 
 	#[inline]
 	fn alpha(&self) -> f64 {
-		unsafe { sys::cv_ppf_match_3d_Pose3D_getPropAlpha_const(self.as_raw_Pose3D()) }.into_result().expect("Infallible function failed: alpha")
+		let ret = unsafe { sys::cv_ppf_match_3d_Pose3D_getPropAlpha_const(self.as_raw_Pose3D()) };
+		ret
 	}
 	
 	#[inline]
 	fn residual(&self) -> f64 {
-		unsafe { sys::cv_ppf_match_3d_Pose3D_getPropResidual_const(self.as_raw_Pose3D()) }.into_result().expect("Infallible function failed: residual")
+		let ret = unsafe { sys::cv_ppf_match_3d_Pose3D_getPropResidual_const(self.as_raw_Pose3D()) };
+		ret
 	}
 	
 	#[inline]
 	fn model_index(&self) -> size_t {
-		unsafe { sys::cv_ppf_match_3d_Pose3D_getPropModelIndex_const(self.as_raw_Pose3D()) }.into_result().expect("Infallible function failed: model_index")
+		let ret = unsafe { sys::cv_ppf_match_3d_Pose3D_getPropModelIndex_const(self.as_raw_Pose3D()) };
+		ret
 	}
 	
 	#[inline]
 	fn num_votes(&self) -> size_t {
-		unsafe { sys::cv_ppf_match_3d_Pose3D_getPropNumVotes_const(self.as_raw_Pose3D()) }.into_result().expect("Infallible function failed: num_votes")
+		let ret = unsafe { sys::cv_ppf_match_3d_Pose3D_getPropNumVotes_const(self.as_raw_Pose3D()) };
+		ret
 	}
 	
 	#[inline]
 	fn pose(&self) -> core::Matx44d {
-		unsafe { sys::cv_ppf_match_3d_Pose3D_getPropPose_const(self.as_raw_Pose3D()) }.into_result().expect("Infallible function failed: pose")
+		let ret = unsafe { sys::cv_ppf_match_3d_Pose3D_getPropPose_const(self.as_raw_Pose3D()) };
+		ret
 	}
 	
 	#[inline]
 	fn angle(&self) -> f64 {
-		unsafe { sys::cv_ppf_match_3d_Pose3D_getPropAngle_const(self.as_raw_Pose3D()) }.into_result().expect("Infallible function failed: angle")
+		let ret = unsafe { sys::cv_ppf_match_3d_Pose3D_getPropAngle_const(self.as_raw_Pose3D()) };
+		ret
 	}
 	
 	#[inline]
 	fn t(&self) -> core::Vec3d {
-		unsafe { sys::cv_ppf_match_3d_Pose3D_getPropT_const(self.as_raw_Pose3D()) }.into_result().expect("Infallible function failed: t")
+		let ret = unsafe { sys::cv_ppf_match_3d_Pose3D_getPropT_const(self.as_raw_Pose3D()) };
+		ret
 	}
 	
 	#[inline]
 	fn q(&self) -> core::Vec4d {
-		unsafe { sys::cv_ppf_match_3d_Pose3D_getPropQ_const(self.as_raw_Pose3D()) }.into_result().expect("Infallible function failed: q")
+		let ret = unsafe { sys::cv_ppf_match_3d_Pose3D_getPropQ_const(self.as_raw_Pose3D()) };
+		ret
 	}
 	
 }
@@ -674,90 +695,107 @@ pub trait Pose3DTrait: crate::surface_matching::Pose3DTraitConst {
 
 	#[inline]
 	fn set_alpha(&mut self, val: f64) {
-		unsafe { sys::cv_ppf_match_3d_Pose3D_setPropAlpha_double(self.as_raw_mut_Pose3D(), val) }.into_result().expect("Infallible function failed: set_alpha")
+		let ret = unsafe { sys::cv_ppf_match_3d_Pose3D_setPropAlpha_double(self.as_raw_mut_Pose3D(), val) };
+		ret
 	}
 	
 	#[inline]
 	fn set_residual(&mut self, val: f64) {
-		unsafe { sys::cv_ppf_match_3d_Pose3D_setPropResidual_double(self.as_raw_mut_Pose3D(), val) }.into_result().expect("Infallible function failed: set_residual")
+		let ret = unsafe { sys::cv_ppf_match_3d_Pose3D_setPropResidual_double(self.as_raw_mut_Pose3D(), val) };
+		ret
 	}
 	
 	#[inline]
 	fn set_model_index(&mut self, val: size_t) {
-		unsafe { sys::cv_ppf_match_3d_Pose3D_setPropModelIndex_size_t(self.as_raw_mut_Pose3D(), val) }.into_result().expect("Infallible function failed: set_model_index")
+		let ret = unsafe { sys::cv_ppf_match_3d_Pose3D_setPropModelIndex_size_t(self.as_raw_mut_Pose3D(), val) };
+		ret
 	}
 	
 	#[inline]
 	fn set_num_votes(&mut self, val: size_t) {
-		unsafe { sys::cv_ppf_match_3d_Pose3D_setPropNumVotes_size_t(self.as_raw_mut_Pose3D(), val) }.into_result().expect("Infallible function failed: set_num_votes")
+		let ret = unsafe { sys::cv_ppf_match_3d_Pose3D_setPropNumVotes_size_t(self.as_raw_mut_Pose3D(), val) };
+		ret
 	}
 	
 	#[inline]
 	fn set_pose(&mut self, val: core::Matx44d) {
-		unsafe { sys::cv_ppf_match_3d_Pose3D_setPropPose_Matx44d(self.as_raw_mut_Pose3D(), val.opencv_as_extern()) }.into_result().expect("Infallible function failed: set_pose")
+		let ret = unsafe { sys::cv_ppf_match_3d_Pose3D_setPropPose_Matx44d(self.as_raw_mut_Pose3D(), val.opencv_as_extern()) };
+		ret
 	}
 	
 	#[inline]
 	fn set_angle(&mut self, val: f64) {
-		unsafe { sys::cv_ppf_match_3d_Pose3D_setPropAngle_double(self.as_raw_mut_Pose3D(), val) }.into_result().expect("Infallible function failed: set_angle")
+		let ret = unsafe { sys::cv_ppf_match_3d_Pose3D_setPropAngle_double(self.as_raw_mut_Pose3D(), val) };
+		ret
 	}
 	
 	#[inline]
 	fn set_t(&mut self, val: core::Vec3d) {
-		unsafe { sys::cv_ppf_match_3d_Pose3D_setPropT_Vec3d(self.as_raw_mut_Pose3D(), val.opencv_as_extern()) }.into_result().expect("Infallible function failed: set_t")
+		let ret = unsafe { sys::cv_ppf_match_3d_Pose3D_setPropT_Vec3d(self.as_raw_mut_Pose3D(), val.opencv_as_extern()) };
+		ret
 	}
 	
 	#[inline]
 	fn set_q(&mut self, val: core::Vec4d) {
-		unsafe { sys::cv_ppf_match_3d_Pose3D_setPropQ_Vec4d(self.as_raw_mut_Pose3D(), val.opencv_as_extern()) }.into_result().expect("Infallible function failed: set_q")
+		let ret = unsafe { sys::cv_ppf_match_3d_Pose3D_setPropQ_Vec4d(self.as_raw_mut_Pose3D(), val.opencv_as_extern()) };
+		ret
 	}
 	
 	/// \brief Updates the pose with the new one
 	/// \param [in] NewPose New pose to overwrite
 	#[inline]
 	fn update_pose(&mut self, new_pose: &mut core::Matx44d) -> Result<()> {
-		unsafe { sys::cv_ppf_match_3d_Pose3D_updatePose_Matx44dR(self.as_raw_mut_Pose3D(), new_pose) }.into_result()
+		let ret = unsafe { sys::cv_ppf_match_3d_Pose3D_updatePose_Matx44dR(self.as_raw_mut_Pose3D(), new_pose) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// \brief Updates the pose with the new one
 	#[inline]
 	fn update_pose_1(&mut self, new_r: &mut core::Matx33d, new_t: &mut core::Vec3d) -> Result<()> {
-		unsafe { sys::cv_ppf_match_3d_Pose3D_updatePose_Matx33dR_Vec3dR(self.as_raw_mut_Pose3D(), new_r, new_t) }.into_result()
+		let ret = unsafe { sys::cv_ppf_match_3d_Pose3D_updatePose_Matx33dR_Vec3dR(self.as_raw_mut_Pose3D(), new_r, new_t) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// \brief Updates the pose with the new one, but this time using quaternions to represent rotation
 	#[inline]
 	fn update_pose_quat(&mut self, q: &mut core::Vec4d, new_t: &mut core::Vec3d) -> Result<()> {
-		unsafe { sys::cv_ppf_match_3d_Pose3D_updatePoseQuat_Vec4dR_Vec3dR(self.as_raw_mut_Pose3D(), q, new_t) }.into_result()
+		let ret = unsafe { sys::cv_ppf_match_3d_Pose3D_updatePoseQuat_Vec4dR_Vec3dR(self.as_raw_mut_Pose3D(), q, new_t) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// \brief Left multiplies the existing pose in order to update the transformation
 	/// \param [in] IncrementalPose New pose to apply
 	#[inline]
 	fn append_pose(&mut self, incremental_pose: &mut core::Matx44d) -> Result<()> {
-		unsafe { sys::cv_ppf_match_3d_Pose3D_appendPose_Matx44dR(self.as_raw_mut_Pose3D(), incremental_pose) }.into_result()
+		let ret = unsafe { sys::cv_ppf_match_3d_Pose3D_appendPose_Matx44dR(self.as_raw_mut_Pose3D(), incremental_pose) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn print_pose(&mut self) -> Result<()> {
-		unsafe { sys::cv_ppf_match_3d_Pose3D_printPose(self.as_raw_mut_Pose3D()) }.into_result()
+		let ret = unsafe { sys::cv_ppf_match_3d_Pose3D_printPose(self.as_raw_mut_Pose3D()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn clone(&mut self) -> Result<core::Ptr<crate::surface_matching::Pose3D>> {
-		unsafe { sys::cv_ppf_match_3d_Pose3D_clone(self.as_raw_mut_Pose3D()) }.into_result().map(|r| unsafe { core::Ptr::<crate::surface_matching::Pose3D>::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_ppf_match_3d_Pose3D_clone(self.as_raw_mut_Pose3D()) }.into_result()?;
+		let ret = unsafe { core::Ptr::<crate::surface_matching::Pose3D>::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn write_pose(&mut self, file_name: &str) -> Result<i32> {
 		extern_container_arg!(file_name);
-		unsafe { sys::cv_ppf_match_3d_Pose3D_writePose_const_stringR(self.as_raw_mut_Pose3D(), file_name.opencv_as_extern()) }.into_result()
+		let ret = unsafe { sys::cv_ppf_match_3d_Pose3D_writePose_const_stringR(self.as_raw_mut_Pose3D(), file_name.opencv_as_extern()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn read_pose(&mut self, file_name: &str) -> Result<i32> {
 		extern_container_arg!(file_name);
-		unsafe { sys::cv_ppf_match_3d_Pose3D_readPose_const_stringR(self.as_raw_mut_Pose3D(), file_name.opencv_as_extern()) }.into_result()
+		let ret = unsafe { sys::cv_ppf_match_3d_Pose3D_readPose_const_stringR(self.as_raw_mut_Pose3D(), file_name.opencv_as_extern()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -791,7 +829,9 @@ impl crate::surface_matching::Pose3DTrait for Pose3D {
 impl Pose3D {
 	#[inline]
 	pub fn default() -> Result<crate::surface_matching::Pose3D> {
-		unsafe { sys::cv_ppf_match_3d_Pose3D_Pose3D() }.into_result().map(|r| unsafe { crate::surface_matching::Pose3D::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_ppf_match_3d_Pose3D_Pose3D() }.into_result()?;
+		let ret = unsafe { crate::surface_matching::Pose3D::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 	/// ## C++ default parameters
@@ -799,7 +839,9 @@ impl Pose3D {
 	/// * num_votes: 0
 	#[inline]
 	pub fn new(alpha: f64, model_index: size_t, num_votes: size_t) -> Result<crate::surface_matching::Pose3D> {
-		unsafe { sys::cv_ppf_match_3d_Pose3D_Pose3D_double_size_t_size_t(alpha, model_index, num_votes) }.into_result().map(|r| unsafe { crate::surface_matching::Pose3D::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_ppf_match_3d_Pose3D_Pose3D_double_size_t_size_t(alpha, model_index, num_votes) }.into_result()?;
+		let ret = unsafe { crate::surface_matching::Pose3D::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 }
@@ -812,17 +854,21 @@ pub trait PoseCluster3DTraitConst {
 
 	#[inline]
 	fn pose_list(&self) -> core::Vector<crate::surface_matching::Pose3DPtr> {
-		unsafe { sys::cv_ppf_match_3d_PoseCluster3D_getPropPoseList_const(self.as_raw_PoseCluster3D()) }.into_result().map(|r| unsafe { core::Vector::<crate::surface_matching::Pose3DPtr>::opencv_from_extern(r) } ).expect("Infallible function failed: pose_list")
+		let ret = unsafe { sys::cv_ppf_match_3d_PoseCluster3D_getPropPoseList_const(self.as_raw_PoseCluster3D()) };
+		let ret = unsafe { core::Vector::<crate::surface_matching::Pose3DPtr>::opencv_from_extern(ret) };
+		ret
 	}
 	
 	#[inline]
 	fn num_votes(&self) -> size_t {
-		unsafe { sys::cv_ppf_match_3d_PoseCluster3D_getPropNumVotes_const(self.as_raw_PoseCluster3D()) }.into_result().expect("Infallible function failed: num_votes")
+		let ret = unsafe { sys::cv_ppf_match_3d_PoseCluster3D_getPropNumVotes_const(self.as_raw_PoseCluster3D()) };
+		ret
 	}
 	
 	#[inline]
 	fn id(&self) -> i32 {
-		unsafe { sys::cv_ppf_match_3d_PoseCluster3D_getPropId_const(self.as_raw_PoseCluster3D()) }.into_result().expect("Infallible function failed: id")
+		let ret = unsafe { sys::cv_ppf_match_3d_PoseCluster3D_getPropId_const(self.as_raw_PoseCluster3D()) };
+		ret
 	}
 	
 }
@@ -832,17 +878,20 @@ pub trait PoseCluster3DTrait: crate::surface_matching::PoseCluster3DTraitConst {
 
 	#[inline]
 	fn set_pose_list(&mut self, mut val: core::Vector<crate::surface_matching::Pose3DPtr>) {
-		unsafe { sys::cv_ppf_match_3d_PoseCluster3D_setPropPoseList_vector_Pose3DPtr_(self.as_raw_mut_PoseCluster3D(), val.as_raw_mut_VectorOfPose3DPtr()) }.into_result().expect("Infallible function failed: set_pose_list")
+		let ret = unsafe { sys::cv_ppf_match_3d_PoseCluster3D_setPropPoseList_vector_Pose3DPtr_(self.as_raw_mut_PoseCluster3D(), val.as_raw_mut_VectorOfPose3DPtr()) };
+		ret
 	}
 	
 	#[inline]
 	fn set_num_votes(&mut self, val: size_t) {
-		unsafe { sys::cv_ppf_match_3d_PoseCluster3D_setPropNumVotes_size_t(self.as_raw_mut_PoseCluster3D(), val) }.into_result().expect("Infallible function failed: set_num_votes")
+		let ret = unsafe { sys::cv_ppf_match_3d_PoseCluster3D_setPropNumVotes_size_t(self.as_raw_mut_PoseCluster3D(), val) };
+		ret
 	}
 	
 	#[inline]
 	fn set_id(&mut self, val: i32) {
-		unsafe { sys::cv_ppf_match_3d_PoseCluster3D_setPropId_int(self.as_raw_mut_PoseCluster3D(), val) }.into_result().expect("Infallible function failed: set_id")
+		let ret = unsafe { sys::cv_ppf_match_3d_PoseCluster3D_setPropId_int(self.as_raw_mut_PoseCluster3D(), val) };
+		ret
 	}
 	
 	/// \brief Adds a new pose to the cluster. The pose should be "close" to the mean poses
@@ -850,19 +899,22 @@ pub trait PoseCluster3DTrait: crate::surface_matching::PoseCluster3DTraitConst {
 	/// \param [in] newPose Pose to add to the cluster
 	#[inline]
 	fn add_pose(&mut self, mut new_pose: crate::surface_matching::Pose3DPtr) -> Result<()> {
-		unsafe { sys::cv_ppf_match_3d_PoseCluster3D_addPose_Pose3DPtr(self.as_raw_mut_PoseCluster3D(), new_pose.as_raw_mut_PtrOfPose3D()) }.into_result()
+		let ret = unsafe { sys::cv_ppf_match_3d_PoseCluster3D_addPose_Pose3DPtr(self.as_raw_mut_PoseCluster3D(), new_pose.as_raw_mut_PtrOfPose3D()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn write_pose_cluster(&mut self, file_name: &str) -> Result<i32> {
 		extern_container_arg!(file_name);
-		unsafe { sys::cv_ppf_match_3d_PoseCluster3D_writePoseCluster_const_stringR(self.as_raw_mut_PoseCluster3D(), file_name.opencv_as_extern()) }.into_result()
+		let ret = unsafe { sys::cv_ppf_match_3d_PoseCluster3D_writePoseCluster_const_stringR(self.as_raw_mut_PoseCluster3D(), file_name.opencv_as_extern()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn read_pose_cluster(&mut self, file_name: &str) -> Result<i32> {
 		extern_container_arg!(file_name);
-		unsafe { sys::cv_ppf_match_3d_PoseCluster3D_readPoseCluster_const_stringR(self.as_raw_mut_PoseCluster3D(), file_name.opencv_as_extern()) }.into_result()
+		let ret = unsafe { sys::cv_ppf_match_3d_PoseCluster3D_readPoseCluster_const_stringR(self.as_raw_mut_PoseCluster3D(), file_name.opencv_as_extern()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -896,17 +948,23 @@ impl crate::surface_matching::PoseCluster3DTrait for PoseCluster3D {
 impl PoseCluster3D {
 	#[inline]
 	pub fn default() -> Result<crate::surface_matching::PoseCluster3D> {
-		unsafe { sys::cv_ppf_match_3d_PoseCluster3D_PoseCluster3D() }.into_result().map(|r| unsafe { crate::surface_matching::PoseCluster3D::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_ppf_match_3d_PoseCluster3D_PoseCluster3D() }.into_result()?;
+		let ret = unsafe { crate::surface_matching::PoseCluster3D::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 	#[inline]
 	pub fn new(mut new_pose: crate::surface_matching::Pose3DPtr) -> Result<crate::surface_matching::PoseCluster3D> {
-		unsafe { sys::cv_ppf_match_3d_PoseCluster3D_PoseCluster3D_Pose3DPtr(new_pose.as_raw_mut_PtrOfPose3D()) }.into_result().map(|r| unsafe { crate::surface_matching::PoseCluster3D::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_ppf_match_3d_PoseCluster3D_PoseCluster3D_Pose3DPtr(new_pose.as_raw_mut_PtrOfPose3D()) }.into_result()?;
+		let ret = unsafe { crate::surface_matching::PoseCluster3D::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 	#[inline]
 	pub fn new_1(mut new_pose: crate::surface_matching::Pose3DPtr, new_id: i32) -> Result<crate::surface_matching::PoseCluster3D> {
-		unsafe { sys::cv_ppf_match_3d_PoseCluster3D_PoseCluster3D_Pose3DPtr_int(new_pose.as_raw_mut_PtrOfPose3D(), new_id) }.into_result().map(|r| unsafe { crate::surface_matching::PoseCluster3D::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_ppf_match_3d_PoseCluster3D_PoseCluster3D_Pose3DPtr_int(new_pose.as_raw_mut_PtrOfPose3D(), new_id) }.into_result()?;
+		let ret = unsafe { crate::surface_matching::PoseCluster3D::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 }
